@@ -403,7 +403,8 @@ connect_now_switch_normal_mode(ConnectNowHomePlugin* desktop_plugin)
 gint
 connect_now_button_release(GtkWidget* widget, GdkEventButton *event, ConnectNowHomePlugin* desktop_plugin)
 {
-  if(desktop_plugin->connection_name == NULL)
+  if(desktop_plugin->connection_name == NULL ||
+     desktop_plugin->connection_id == NULL)
   {
     con_ic_connection_connect(desktop_plugin->con, 
 			      CON_IC_CONNECT_FLAG_NONE);
