@@ -132,18 +132,28 @@ load_image(const gchar* image_name)
 					      CONNECTNOW_DEFAULT_WIDGET_WIDTH,
 					      0,
 					      NULL);
-  if(!image)
+  if(image == NULL)
   {
-    image = gdk_pixbuf_new_from_file_at_size(image_name,
-					     CONNECTNOW_DEFAULT_WIDGET_WIDTH,
-					     CONNECTNOW_DEFAULT_WIDGET_WIDTH,
-					     NULL);
+    image = gdk_pixbuf_new_from_file_at_scale(image_name,
+					      CONNECTNOW_DEFAULT_WIDGET_WIDTH,
+					      CONNECTNOW_DEFAULT_WIDGET_WIDTH,
+					      FALSE,
+					      NULL);
   }
-  if(!image)
+  if(image == NULL)
   {
     gchar* fullpath = g_strdup_printf("/usr/share/icons/hicolor/96x96/hildon/%s.png", image_name);
-    image = load_image(fullpath);
+    image = gdk_pixbuf_new_from_file_at_scale(fullpath,
+					      CONNECTNOW_DEFAULT_WIDGET_WIDTH,
+					      CONNECTNOW_DEFAULT_WIDGET_WIDTH,
+					      FALSE,
+					      NULL);
     g_free(fullpath);
   }
+  if(image == NULL)
+  {
+    g_warning("warning can not load icon %s",image_name);
+  }
+
   return image;
 }
